Aiuti
=====

This Python package is my personal collection of helpers and utilities
that I have written for various projects but don't have to be maintained
with those projects.

It has no required dependencies and is MIT licenced in order to make it
as portable and easy to use as possible.

.. uncomment on first release

    Installation
    ------------

    This package can be installed through the official PyPI:

    .. code-block:: sh

        $ pip install aiuti

    Documentation
    -------------

    The documentation can be found on `Read the Docs
    <https://aiuti.readthedocs.io/en/latest/>`__.
